<?php
if (!function_exists('blogbull_get_option')) :
    /**
     * Get customizer value by key.
     *
     * @param string $key Option key.
     * @return mixed Option value.
     * @since 1.0.0
     *
     */
    function blogbull_get_option($key)
    {
        $key_value = '';
        if (!$key) {
            return $key_value;
        }
        $default_values = blogbull_get_all_customizer_default_values();
        $customizer_values = get_theme_mod('blogbull_options');
        $customizer_values = wp_parse_args($customizer_values, $default_values);

        $key_value = (isset($customizer_values[$key])) ? $customizer_values[$key] : '';
        return $key_value;
    }
endif;

if ( ! function_exists( 'blogbull_get_archive_layouts' ) ) :
	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_archive_layouts() {
		$options = apply_filters(
			'blogbull_get_archive_layouts',
			array(
				'archive_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-1.webp',
					'label' => esc_html__( 'Archive List View', 'blogbull' ),
				),
				'archive_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-2.webp',
					'label' => esc_html__( 'Archive Grid View', 'blogbull' ),
				),
				'archive_style_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/archive-3.webp',
					'label' => esc_html__( 'Archive Alternate Grid View', 'blogbull' ),
				),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_get_date_formats' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_date_formats() {
		$options = apply_filters(
			'blogbull_archive_date_format',
			array(
				'classic'   => __( 'Classic', 'blogbull' ),
				'time_ago' => __( 'Time Ago', 'blogbull' ),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_line_limit_choices' ) ) :
	/**
	 * Returns title limit options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_line_limit_choices() {
		$options = apply_filters(
			'blogbull_title_limit_options',
			array(
				''              => __( '&mdash; No Limit &mdash;', 'blogbull' ),
				'limit-line-1' => __( '1 Line', 'blogbull' ),
				'limit-line-2' => __( '2 Lines', 'blogbull' ),
				'limit-line-3' => __( '3 Lines', 'blogbull' ),
				'limit-line-4' => __( '4 Lines', 'blogbull' ),
				'limit-line-5' => __( '5 Lines', 'blogbull' ),
			)
		);
		return $options;
	}
endif;
if ( ! function_exists( 'blogbull_archive_category_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_archive_category_style() {
		$options = apply_filters(
			'blogbull_archive_category_style',
			array(
				'archive_cat_style_1'   => __( 'Category Style 1', 'blogbull' ),
				'archive_cat_style_2'   => __( 'Category Style 2', 'blogbull' ),
				'archive_cat_style_3'   => __( 'Category Style 3', 'blogbull' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_archive_read_time_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_archive_read_time_style() {
		$options = apply_filters(
			'blogbull_archive_read_time_style',
			array(
				'archive_read_time_style_1'   => __( 'Read Time Style 1', 'blogbull' ),
				'archive_read_time_style_2'   => __( 'Read Time Style 2', 'blogbull' ),
				'archive_read_time_style_3'   => __( 'Read Time Style 3', 'blogbull' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_get_header_layout' ) ) :
	/**
	 * Returns header layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_header_layout() {
		$options = apply_filters(
			'blogbull_get_header_layout',
			array(
				'header_style_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-1.webp',
					'label' => esc_html__( 'Header Style 1', 'blogbull' ),
				),
				'header_style_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/header-2.webp',
					'label' => esc_html__( 'Header Style 2', 'blogbull' ),
				),
                'header_style_3' => array(
                    'url'   => get_template_directory_uri() . '/assets/images/header-3.webp',
                    'label' => esc_html__( 'Header Style 3', 'blogbull' ),
                ),
			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_social_menu_style' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_social_menu_style() {
		$options = apply_filters(
			'blogbull_social_menu_style',
			array(
				'has-brand-background'   => __( 'Has Brand Background', 'blogbull' ),
				'has-brand-color'   => __( 'Has Brand Color', 'blogbull' ),
				'none'   => __( 'None', 'blogbull' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_pagination_style_choice' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_pagination_style_choice() {
		$options = apply_filters(
			'blogbull_pagination_style_choice',
			array(
				'pagination_none'   => __( 'None', 'blogbull' ),
				'pagination_numeric'   => __( 'Numeric', 'blogbull' ),
				'pagination_default'   => __( 'Default(New/Old Post)', 'blogbull' ),
				'pagination_ajax_on_scroll'   => __( 'Load More On Scroll', 'blogbull' ),
				'pagination_ajax_on_click'   => __( 'Load More On Click', 'blogbull' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_category_color' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_category_color() {
		$options = apply_filters(
			'blogbull_category_color',
			array(
				'none'   => __( 'None', 'blogbull' ),
				'has-background'   => __( 'Has background', 'blogbull' ),
				'has-text-color'   => __( 'Has text color', 'blogbull' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_get_footer_layouts' ) ) :
	/**
	 * Returns footer layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_footer_layouts() {
		$options = apply_filters(
			'blogbull_footer_layouts',
			array(
				'footer_layout_1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-4.webp',
					'label' => esc_html__( 'Four Columns', 'blogbull' ),
				),
				'footer_layout_2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3.webp',
					'label' => esc_html__( 'Three Columns', 'blogbull' ),
				),
				'footer_layout_3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2.webp',
					'label' => esc_html__( 'Two Columns', 'blogbull' ),
				),
				'footer_layout_4' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-left.webp',
					'label' => esc_html__( 'Two Columns Big Left', 'blogbull' ),
				),
				'footer_layout_5' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-3-big-middle.webp',
					'label' => esc_html__( 'Three Columns Big Middle', 'blogbull' ),
				),
				'footer_layout_6' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-2-big-right.webp',
					'label' => esc_html__( 'Two Columns Big Right', 'blogbull' ),
				),
				'footer_layout_7' => array(
					'url'   => get_template_directory_uri() . '/assets/images/footer-col-1.webp',
					'label' => esc_html__( 'Single Column', 'blogbull' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_preloader_style_option' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_preloader_style_option() {
		$options = apply_filters(
			'blogbull_preloader_style_option',
			array(
				'style-1'   => __( 'Style - 1', 'blogbull' ),
				'style-2'   => __( 'Style - 2', 'blogbull' ),
				'style-3'   => __( 'Style - 3', 'blogbull' ),
				'style-4'   => __( 'Style - 4', 'blogbull' ),
				'style-5'   => __( 'Style - 5', 'blogbull' ),
				'style-6'   => __( 'Style - 6', 'blogbull' ),
				'style-7'   => __( 'Style - 7', 'blogbull' ),
				'style-8'   => __( 'Style - 8', 'blogbull' ),
				'style-9'   => __( 'Style - 9', 'blogbull' ),
				'style-10'   => __( 'Style - 10', 'blogbull' ),

			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_get_recommended_post' ) ) :
	/**
	 * Returns recommended layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_recommended_post() {
		$options = apply_filters(
			'blogbull_get_recommended_post',
			array(
				'wpi-post-recommendation-1' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-1.webp',
					'label' => esc_html__( 'Recommended List View', 'blogbull' ),
				),
				'wpi-post-recommendation-2' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-2.webp',
					'label' => esc_html__( 'Recommended Grid View', 'blogbull' ),
				),
				'wpi-post-recommendation-3' => array(
					'url'   => get_template_directory_uri() . '/assets/images/recommended-3.webp',
					'label' => esc_html__( 'Recommended Alternate Grid View', 'blogbull' ),
				),
			)
		);
		return $options;
	}
endif;



if ( ! function_exists( 'blogbull_author_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_author_meta() {
		$options = apply_filters(
			'blogbull_author_meta',
			array(
				'with_label'   => __( 'With Label', 'blogbull' ),
				'with_icon'   => __( 'With Icon', 'blogbull' ),
				'with_avatar_image'   => __( 'With Avatar Image', 'blogbull' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_date_meta' ) ) :
	/**
	 * Returns title Alignments
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_date_meta() {
		$options = apply_filters(
			'blogbull_date_meta',
			array(
				'with_label'   => __( 'With Label', 'blogbull' ),
				'with_icon'   => __( 'With Icon', 'blogbull' ),

			)
		);
		return $options;
	}
endif;

if ( ! function_exists( 'blogbull_get_sidebar_layouts' ) ) :
	/**
	 * Returns general layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_sidebar_layouts() {
		$options = apply_filters(
			'blogbull_sidebar_layouts',
			array(
				'left-sidebar'      => array(
					'url'   => get_template_directory_uri() . '/assets/images/left-sidebar.webp',
					'label' => esc_html__( 'Left Sidebar', 'blogbull' ),
				),
				'right-sidebar'     => array(
					'url'   => get_template_directory_uri() . '/assets/images/right-sidebar.webp',
					'label' => esc_html__( 'Right Sidebar', 'blogbull' ),
				),
				'no-sidebar'        => array(
					'url'   => get_template_directory_uri() . '/assets/images/no-sidebar.webp',
					'label' => esc_html__( 'No Sidebar - Wide', 'blogbull' ),
				),
			)
		);
		return $options;
	}
endif;


if ( ! function_exists( 'blogbull_get_social_links_styles' ) ) :
	/**
	 * Returns social links styles options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function blogbull_get_social_links_styles() {
		$options = apply_filters(
			'blogbull_social_links_styles',
			array(
				'style_1' => __( 'Style 1', 'blogbull' ),
				'style_2' => __( 'Style 2', 'blogbull' ),
				'style_3' => __( 'Style 3', 'blogbull' ),
				'style_4' => __( 'Style 4', 'blogbull' ),
			)
		);
		return $options;
	}
endif;
