<?php
/**
 * All settings related to archive.
 *
 * @package BlogBull
 */
$wp_customize->add_section(
	'archive_options',
	array(
		'title' => esc_html__( 'Archive Options', 'blogbull' ),
		'panel' => 'archive_options_panel',
	)
);

// Archive Layout.
$wp_customize->add_setting(
    'blogbull_options[archive_layout]',
    array(
        'default'           => $blogbull_default['archive_layout'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'blogbull_sanitize_radio'
    )
);

$wp_customize->add_control(
    new Blogbull_Custom_Radio_Image_Control(
        $wp_customize,
        'blogbull_options[archive_layout]',
        array(
            'label'         => esc_html__( 'Archive Layout', 'blogbull' ),
            'section'       => 'archive_options',
            'choices'       => blogbull_get_archive_layouts(),
        )
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_archive_featured_post]',
    array(
        'default'           => $blogbull_default['enable_archive_featured_post'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_archive_featured_post]',
    array(
        'label'    => __( 'Enable Featured Post', 'blogbull' ),
        'description' => __( 'After enabling, set \'Mark as Featured\' to \'Yes\' in the single post options to display the post in the top section of the relevant archive page.', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',

    )
);

$wp_customize->add_setting(
    'blogbull_section_seperator_archive_1',
    array(
        'default'           => '',
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'sanitize_text_field'
    )
);

$wp_customize->add_control(
    new Blogbull_Seperator_Control(
        $wp_customize,
        'blogbull_section_seperator_archive_1',
        array(
            'label'         => esc_html__( 'Archive Meta Options', 'blogbull' ),
            'settings' => 'blogbull_section_seperator_archive_1',
            'section' => 'archive_options',
        )
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_archive_post_count]',
    array(
        'default'           => $blogbull_default['enable_archive_post_count'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_archive_post_count]',
    array(
        'label'    => __( 'Enable Archive Post Count', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',

    )
);


$wp_customize->add_setting(
    'blogbull_options[archive_posts_title_limit]',
    array(
        'default'           => $blogbull_default['archive_posts_title_limit'],
        'sanitize_callback' => 'blogbull_sanitize_select',
    )
);
$wp_customize->add_control(
    'blogbull_options[archive_posts_title_limit]',
    array(
        'label'    => __( 'Title Line Limit', 'blogbull' ),
        'section'  => 'archive_options',
        'type'     => 'select',
        'choices'  => blogbull_line_limit_choices(),
    )
);


$wp_customize->add_setting(
    'blogbull_options[enable_excerpt_on_archive_1]',
    array(
        'default'           => $blogbull_default['enable_excerpt_on_archive_1'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_excerpt_on_archive_1]',
    array(
        'label'    => __( 'Enable Excerpt On Archive', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
        'active_callback' => 'blogbull_is_archive_excerpt_callbac_1',

    )
);



$wp_customize->add_setting(
    'blogbull_options[enable_excerpt_on_archive_2]',
    array(
        'default'           => $blogbull_default['enable_excerpt_on_archive_2'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_excerpt_on_archive_2]',
    array(
        'label'    => __( 'Enable Excerpt On Archive', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
        'active_callback' => 'blogbull_is_archive_excerpt_callbac_2',
        
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_archive_author_meta]',
    array(
        'default'           => $blogbull_default['enable_archive_author_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_archive_author_meta]',
    array(
        'label'       => esc_html__( 'Show Author Meta', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'blogbull_options[select_author_meta]',
    array(
        'default'           => $blogbull_default['select_author_meta'],
        'sanitize_callback' => 'blogbull_sanitize_select',
    )
);
$wp_customize->add_control(
    'blogbull_options[select_author_meta]',
    array(
        'label'         => esc_html__( 'Author Meta Display Options', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'       => blogbull_author_meta(),
        'active_callback' => 'blogbull_is_archive_author_meta_enabled',


    )
);

$wp_customize->add_setting(
    'blogbull_options[archive_author_meta_title]',
    array(
        'default'           => $blogbull_default['archive_author_meta_title'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'blogbull_options[archive_author_meta_title]',
    array(
        'label'    => __( 'Author Meta Text', 'blogbull' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => function ( $control ) {
            return (
                blogbull_is_archive_author_meta_enabled( $control )
                &&
                blogbull_archive_author_meta_title( $control )
            );
        },
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_archive_date_meta]',
    array(
        'default'           => $blogbull_default['enable_archive_date_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_archive_date_meta]',
    array(
        'label'       => esc_html__( 'Show Date Meta', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'blogbull_options[select_archive_date]',
    array(
        'default'           => $blogbull_default['select_archive_date'],
        'sanitize_callback' => 'blogbull_sanitize_select',
    )
);
$wp_customize->add_control(
    'blogbull_options[select_archive_date]',
    array(
        'label'         => esc_html__( 'Date Meta Display Options', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'       => blogbull_date_meta(),
        'active_callback' => 'blogbull_is_archive_date_meta_enabled',

    )
);

$wp_customize->add_setting(
    'blogbull_options[archive_date_meta_title]',
    array(
        'default'           => $blogbull_default['archive_date_meta_title'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'blogbull_options[archive_date_meta_title]',
    array(
        'label'    => __( 'Date Text', 'blogbull' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => function ( $control ) {
            return (
                blogbull_is_archive_date_meta_enabled( $control )
                &&
                blogbull_archive_date_meta_title( $control )
            );
        },
    )
);

$wp_customize->add_setting(
    'blogbull_options[select_date_format]',
    array(
        'default'           => $blogbull_default['select_date_format'],
        'sanitize_callback' => 'blogbull_sanitize_select',
    )
);
$wp_customize->add_control(
    'blogbull_options[select_date_format]',
    array(
        'label'         => esc_html__( 'Select Date Format', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'  		=> blogbull_get_date_formats(),
        'active_callback' => 'blogbull_is_archive_date_meta_enabled',
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_category_meta]',
    array(
        'default'           => $blogbull_default['enable_category_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_category_meta]',
    array(
        'label'       => esc_html__( 'Enable Category Meta', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'blogbull_options[number_of_category_to_display]',
    array(
        'default' => $blogbull_default['number_of_category_to_display'],
        'sanitize_callback' => 'absint',
    )
);
$wp_customize->add_control(
    'blogbull_options[number_of_category_to_display]',
    array(
        'label' => __('Number of Category', 'blogbull'),
        'section' => 'archive_options',
        'type' => 'number',
    )
);

$wp_customize->add_setting(
    'blogbull_options[archive_category_label]',
    array(
        'default'           => $blogbull_default['archive_category_label'],
        'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control(
    'blogbull_options[archive_category_label]',
    array(
        'label'    => __( 'Category Title', 'blogbull' ),
        'section'  => 'archive_options',
        'type'     => 'text',
        'active_callback' => 'blogbull_is_archive_category_meta_enabled',
    )
);

$wp_customize->add_setting(
    'blogbull_options[select_category_color]',
    array(
        'default'           => $blogbull_default['select_category_color'],
        'sanitize_callback' => 'blogbull_sanitize_select',
    )
);
$wp_customize->add_control(
    'blogbull_options[select_category_color]',
    array(
        'label'         => esc_html__( 'Select Category Color', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'select',
        'choices'  		=> blogbull_category_color(),
        'active_callback' => 'blogbull_is_archive_category_meta_enabled',

    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_tag_meta]',
    array(
        'default'           => $blogbull_default['enable_tag_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_tag_meta]',
    array(
        'label'       => esc_html__( 'Enable Tag Meta', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);

$wp_customize->add_setting(
    'blogbull_options[enable_comment_meta]',
    array(
        'default'           => $blogbull_default['enable_comment_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_comment_meta]',
    array(
        'label'       => esc_html__( 'Enable Comment Meta', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);


$wp_customize->add_setting(
    'blogbull_options[enable_read_time_meta]',
    array(
        'default'           => $blogbull_default['enable_read_time_meta'],
        'sanitize_callback' => 'blogbull_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'blogbull_options[enable_read_time_meta]',
    array(
        'label'       => esc_html__( 'Enable Read Time', 'blogbull' ),
        'section'     => 'archive_options',
        'type'        => 'checkbox',
    )
);
